==> tempest2-testing-docker-1.4.0-javadoc.jar: tempest-testing-internal/app.cash.tempest.testing.internal/index.md <==
[tempest-testing-internal](../index.md) / [app.cash.tempest.testing.internal](./index.md)

## Package app.cash.tempest.testing.internal

### Types

| Name | Summary |
|---|---|
| [DefaultTestDynamoDbClient](-default-test-dynamo-db-client/index.md) | `class DefaultTestDynamoDbClient : AbstractIdleService, TestDynamoDbClient` |

### Type Aliases

| Name | Summary |
|---|---|
| [Tag](-tag.md) | `typealias Tag = `[`Pair`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`?>` |

### Extensions for External Classes

| Name | Summary |
|---|---|
| [com.amazonaws.services.dynamodbv2.AmazonDynamoDB](com.amazonaws.services.dynamodbv2.-amazon-dynamo-d-b/index.md) |  |
| [mu.KLogger](mu.-k-logger/index.md) |  |

### Functions

| Name | Summary |
|---|---|
| [connect](connect.md) | `fun connect(port: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`AmazonDynamoDB`](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDB.html) |
| [connectToStreams](connect-to-streams.md) | `fun connectToStreams(port: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`AmazonDynamoDBStreams`](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDBStreams.html) |
| [getLogger](get-logger.md) | `fun <T> getLogger(): KLogger` |
| [pickRandomPort](pick-random-port.md) | `fun pickRandomPort(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |

==> tempest2-testing-docker-1.5.2-javadoc.jar: tempest-testing-internal/app.cash.tempest.testing.internal/index.md <==
[tempest-testing-internal](../index.md) / [app.cash.tempest.testing.internal](./index.md)

## Package app.cash.tempest.testing.internal

### Types

| Name | Summary |
|---|---|
| [DefaultTestDynamoDbClient](-default-test-dynamo-db-client/index.md) | `class DefaultTestDynamoDbClient : AbstractIdleService, TestDynamoDbClient` |
| [TestDynamoDbService](-test-dynamo-db-service/index.md) | `class TestDynamoDbService : AbstractIdleService`<br>This Guava service spins up a DynamoDB server in tests. It shares the server across tests and keeps the server running until the process exits. |

### Type Aliases

| Name | Summary |
|---|---|
| [Tag](-tag.md) | `typealias Tag = `[`Pair`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`?>` |

### Extensions for External Classes

| Name | Summary |
|---|---|
| [com.amazonaws.services.dynamodbv2.AmazonDynamoDB](com.amazonaws.services.dynamodbv2.-amazon-dynamo-d-b/index.md) |  |
| [mu.KLogger](mu.-k-logger/index.md) |  |

### Functions

| Name | Summary |
|---|---|
| [connect](connect.md) | `fun connect(port: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`AmazonDynamoDB`](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDB.html) |
| [connectToStreams](connect-to-streams.md) | `fun connectToStreams(port: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): `[`AmazonDynamoDBStreams`](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDBStreams.html) |
| [getLogger](get-logger.md) | `fun <T> getLogger(): KLogger` |
| [pickRandomPort](pick-random-port.md) | `fun pickRandomPort(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
